Learn R Programming

vembedr (version 0.1.1)

rickroll: Embeds a popular video

Description

If you want to experiment with the arguments to embed, such as query, but do not have a particular video in mind, this function may be useful to you.

Usage

rickroll_vimeo(...)
rickroll_youtube(...)
rickroll_channel9(...)

Arguments

...
arguments (other than id) passed on to embed

Value

html element

Examples

Run this code
  rickroll_vimeo()
  rickroll_youtube()
  rickroll_channel9() %>% use_start_time("5m03s")

Run the code above in your browser using DataLab