Learn R Programming

vembedr (version 0.1.1)

use_start_time: Specify a start time for an embedded video

Description

Please not that for Vimeo, you may specify a start time, but you can not specify that the video be paused at this time. In other words, it is like "autoplay" is set to TRUE, and you cannot unset it.

Usage

use_start_time(...)
"use_start_time"(...)
"use_start_time"(embed, start_time, ...)
"use_start_time"(embed, start_time, ...)
"use_start_time"(embed, start_time, is_paused = TRUE, ...)

Arguments

...
generic args to pass through
embed
embed object, i.e. embed_youtube
start_time
numeric (seconds), or character ("3m15s")
is_paused
logical, for "Channel 9" specifies if the video should be paused at this time

Examples

Run this code
  rickroll_youtube() %>%
    use_start_time("3m32s")

Run the code above in your browser using DataLab